@@ -230,7 +230,7 @@ class AbsMilvus:
         """
         pass
 
-    def get_index_process(self, collection_name, field_name, timeout=30):
+    def get_index_progress(self, collection_name, field_name, timeout=30):
         """
         Show index information of a collection.
 
@@ -630,3 +630,7 @@ class AbsMilvus:
 
         """
         pass
+
+    def wait_index_building_success(self, collection_name, field_name, timeout=30):
+
+        pass
