@@ -34,3 +34,6 @@ def vectorFloatToBytes(v):
     for f in v:
         bs += floatToBytes(f)
     return bs
+
+def bytesToInt64(v):
+    return struct.unpack("q", v)[0]
