@@ -8,12 +8,9 @@ import ujson
 import grpc
 from grpc._cython import cygrpc
 
+from ..grpc_gen import common_pb2 as common_types
 from ..grpc_gen import milvus_pb2_grpc
-from ..grpc_gen import milvus_pb2 as grpc_types
-from ..grpc_gen import service_pb2_grpc
-from ..grpc_gen import service_pb2 as service_types
-from ..grpc_gen import service_pb2_grpc
-from ..grpc_gen import service_msg_pb2 as service_msg_types
+from ..grpc_gen import milvus_pb2 as milvus_types
 from .abstract import QueryResult, CollectionSchema
 from .prepare import Prepare
 from .types import Status
@@ -24,7 +21,7 @@ from .check import (
 )
 
 from .abs_client import AbsMilvus
-from .asynch import SearchFuture, InsertFuture, CreateIndexFuture, CompactFuture, FlushFuture
+from .asynch import SearchFuture, InsertFuture, CreateIndexFuture
 
 from .hooks import BaseSearchHook
 from .client_hooks import SearchHook, HybridSearchHook
@@ -56,15 +53,18 @@ def error_handler(*rargs):
 
             except grpc.FutureTimeoutError as e:
                 record_dict["RPC timeout"] = str(datetime.datetime.now())
-                LOGGER.error("\nAddr [{}] {}\nRequest timeout: {}\n\t{}".format(self.server_address, func.__name__, e, record_dict))
+                LOGGER.error("\nAddr [{}] {}\nRequest timeout: {}\n\t{}".format(self.server_address, func.__name__, e,
+                                                                                record_dict))
                 raise e
             except grpc.RpcError as e:
                 record_dict["RPC error"] = str(datetime.datetime.now())
-                LOGGER.error("\nAddr [{}] {}\nRPC error: {}\n\t{}".format(self.server_address, func.__name__, e, record_dict))
+                LOGGER.error(
+                    "\nAddr [{}] {}\nRPC error: {}\n\t{}".format(self.server_address, func.__name__, e, record_dict))
                 raise e
             except Exception as e:
                 record_dict["Exception"] = str(datetime.datetime.now())
-                LOGGER.error("\nAddr [{}] {}\nExcepted error: {}\n\t{}".format(self.server_address, func.__name__, e, record_dict))
+                LOGGER.error("\nAddr [{}] {}\nExcepted error: {}\n\t{}".format(self.server_address, func.__name__, e,
+                                                                               record_dict))
                 raise e
 
         return handler
@@ -94,6 +94,115 @@ def set_uri(host, port, uri):
     return "{}:{}".format(str(_host), str(_port))
 
 
+class RegistryHandler:
+    def __init__(self, host=None, port=None, pre_ping=True, **kwargs):
+        self._channel = None
+        self._stub = None
+        self._uri = None
+        self.status = None
+        self._connected = False
+        self._pre_ping = pre_ping
+        # if self._pre_ping:
+        self._max_retry = kwargs.get("max_retry", 5)
+
+        # record
+        self._id = kwargs.get("conn_id", 0)
+
+        # condition
+        self._condition = threading.Condition()
+        self._request_id = 0
+
+        # set server uri if object is initialized with parameter
+        _uri = kwargs.get("uri", None)
+        self._setup(host, port, _uri, pre_ping)
+
+    def __str__(self):
+        attr_list = ['%s=%r' % (key, value)
+                     for key, value in self.__dict__.items() if not key.startswith('_')]
+        return '<Milvus: {}>'.format(', '.join(attr_list))
+
+    def __enter__(self):
+        return self
+
+    def __exit__(self, exc_type, exc_val, exc_tb):
+        # self._channel.close()
+        pass
+
+    def _setup(self, host, port, uri, pre_ping=False):
+        """
+        Create a grpc channel and a stub
+
+        :raises: NotConnectError
+
+        """
+        self._uri = set_uri(host, port, uri)
+        self._channel = grpc.insecure_channel(
+            self._uri,
+            options=[(cygrpc.ChannelArgKey.max_send_message_length, -1),
+                     (cygrpc.ChannelArgKey.max_receive_message_length, -1),
+                     ('grpc.enable_retries', 1),
+                     ('grpc.keepalive_time_ms', 55000)]
+        )
+        # self._stub = milvus_pb2_grpc.MilvusServiceStub(self._channel)
+        self._stub = milvus_pb2_grpc.ProxyServiceStub(self._channel)
+        self.status = Status()
+
+    def _pre_request(self):
+        if self._pre_ping:
+            self.ping()
+
+    def _get_request_id(self):
+        with self._condition:
+            _id = self._request_id
+            self._request_id += 1
+            return _id
+
+    def ping(self):
+        begin_timeout = 1
+        timeout = begin_timeout
+        ft = grpc.channel_ready_future(self._channel)
+        retry = self._max_retry
+        try:
+            while retry > 0:
+                try:
+                    ft.result(timeout=timeout)
+                    return True
+                except:
+                    retry -= 1
+                    LOGGER.debug("Retry connect addr <{}> {} times".format(self._uri, self._max_retry - retry))
+                    if retry > 0:
+                        timeout *= 2
+                        continue
+                    else:
+                        LOGGER.error("Retry to connect server {} failed.".format(self._uri))
+                        raise
+        except grpc.FutureTimeoutError:
+            raise NotConnectError('Fail connecting to server on {}. Timeout'.format(self._uri))
+        except grpc.RpcError as e:
+            raise NotConnectError("Connect error: <{}>".format(e))
+        # Unexpected error
+        except Exception as e:
+            raise NotConnectError("Error occurred when trying to connect server:\n"
+                                  "\t<{}>".format(str(e)))
+
+    @property
+    def server_address(self):
+        """
+        Server network address
+        """
+        return self._uri
+
+    @error_handler(None)
+    def register_link(self, timeout=20):
+        request = common_types.Empty()
+        rf = self._stub.RegisterLink.future(request, wait_for_ready=True, timeout=timeout)
+        response = rf.result()
+        if response.status.error_code != 0:
+            LOGGER.error(response.status)
+            raise BaseException(response.status.error_code, response.status.reason)
+        return response.address.ip, response.address.port
+
+
 class GrpcHandler(AbsMilvus):
     def __init__(self, host=None, port=None, pre_ping=True, **kwargs):
         self._channel = None
@@ -148,7 +257,7 @@ class GrpcHandler(AbsMilvus):
                      ('grpc.keepalive_time_ms', 55000)]
         )
         # self._stub = milvus_pb2_grpc.MilvusServiceStub(self._channel)
-        self._stub = service_pb2_grpc.MilvusServiceStub(self._channel)
+        self._stub = milvus_pb2_grpc.MilvusServiceStub(self._channel)
         self.status = Status()
 
     def _pre_request(self):
@@ -224,9 +333,9 @@ class GrpcHandler(AbsMilvus):
 
     @error_handler()
     def create_collection(self, collection_name, fields, timeout=30):
-        collection_schema = Prepare.collection_schema(collection_name, fields)
+        request = Prepare.create_collection_request(collection_name, fields)
 
-        rf = self._stub.CreateCollection.future(collection_schema, wait_for_ready=True, timeout=timeout)
+        rf = self._stub.CreateCollection.future(request, wait_for_ready=True, timeout=timeout)
         status = rf.result()
         if status.error_code != 0:
             LOGGER.error(status)
@@ -236,9 +345,9 @@ class GrpcHandler(AbsMilvus):
 
     @error_handler()
     def drop_collection(self, collection_name, timeout=20):
-        collection_name = Prepare.collection_name(collection_name)
+        request = Prepare.drop_collection_request(collection_name)
 
-        rf = self._stub.DropCollection.future(collection_name, wait_for_ready=True, timeout=timeout)
+        rf = self._stub.DropCollection.future(request, wait_for_ready=True, timeout=timeout)
         status = rf.result()
         if status.error_code != 0:
             raise BaseException(status.error_code, status.reason)
@@ -247,9 +356,9 @@ class GrpcHandler(AbsMilvus):
 
     @error_handler(False)
     def has_collection(self, collection_name, timeout=30, **kwargs):
-        collection_name = Prepare.collection_name(collection_name)
+        request = Prepare.has_collection_request(collection_name)
 
-        rf = self._stub.HasCollection.future(collection_name, wait_for_ready=True, timeout=timeout)
+        rf = self._stub.HasCollection.future(request, wait_for_ready=True, timeout=timeout)
         reply = rf.result()
         if reply.status.error_code == 0:
             # return Status(reply.status.error_code, reply.status.reason), reply.value
@@ -259,33 +368,34 @@ class GrpcHandler(AbsMilvus):
 
     @error_handler(None)
     def get_collection_info(self, collection_name, timeout=30, **kwargs):
-        collection_name = Prepare.collection_name(collection_name)
-        rf = self._stub.DescribeCollection.future(collection_name, wait_for_ready=True, timeout=timeout)
+        # TODO: which request
+        request = Prepare.describe_collection_request(collection_name)
+        rf = self._stub.DescribeCollection.future(request, wait_for_ready=True, timeout=timeout)
         response = rf.result()
         status = response.status
 
-        if response.status.error_code == 0:
+        if status.error_code == 0:
             # return Status(status.error_code, status.reason), CollectionSchema(raw=response).dict()
             return CollectionSchema(raw=response).dict()
 
-        LOGGER.error(response.status)
-        raise BaseException(response.status.error_code, response.status.reason)
+        LOGGER.error(status)
+        raise BaseException(status.error_code, status.reason)
         # return Status(status.error_code, status.reason), CollectionSchema(None)
 
     @error_handler([])
     def list_collections(self, timeout=30):
-        empty = Prepare.empty()
-        rf = self._stub.ShowCollections.future(empty, wait_for_ready=True, timeout=timeout)
+        request = Prepare.show_collection_request()
+        rf = self._stub.ShowCollections.future(request, wait_for_ready=True, timeout=timeout)
         response = rf.result()
         status = response.status
         if response.status.error_code == 0:
             # return Status(status.error_code, status.reason), [name for name in response.values if len(name) > 0]
-            return [name for name in response.values if len(name) > 0]
+            return list(response.collection_names)
         raise BaseException(status.error_code, status.reason)
 
     @error_handler()
     def create_partition(self, collection_name, partition_tag, timeout=30):
-        request = Prepare.partition_name(collection_name, partition_tag)
+        request = Prepare.create_partition_request(collection_name, partition_tag)
         rf = self._stub.CreatePartition.future(request, wait_for_ready=True, timeout=timeout)
         response = rf.result()
         if response.error_code != 0:
@@ -294,7 +404,7 @@ class GrpcHandler(AbsMilvus):
 
     @error_handler()
     def drop_partition(self, collection_name, partition_tag, timeout=30):
-        request = Prepare.partition_name(collection_name, partition_tag)
+        request = Prepare.drop_partition_request(collection_name, partition_tag)
 
         rf = self._stub.DropPartition.future(request, wait_for_ready=True, timeout=timeout)
         response = rf.result()
@@ -306,7 +416,7 @@ class GrpcHandler(AbsMilvus):
 
     @error_handler(False)
     def has_partition(self, collection_name, partition_tag, timeout=30):
-        request = Prepare.partition_name(collection_name, partition_tag)
+        request = Prepare.has_partition_request(collection_name, partition_tag)
         rf = self._stub.HasPartition.future(request, wait_for_ready=True, timeout=timeout)
         response = rf.result()
         status = response.status
@@ -317,7 +427,7 @@ class GrpcHandler(AbsMilvus):
 
     @error_handler(None)
     def get_partition_info(self, collection_name, partition_tag, timeout=30):
-        request = Prepare.partition_name(collection_name, partition_tag)
+        request = Prepare.partition_stats_request(collection_name, partition_tag)
         rf = self._stub.DescribePartition.future(request, wait_for_ready=True, timeout=timeout)
         response = rf.result()
         status = response.status
@@ -331,13 +441,13 @@ class GrpcHandler(AbsMilvus):
 
     @error_handler([])
     def list_partitions(self, collection_name, timeout=30):
-        request = Prepare.collection_name(collection_name)
+        request = Prepare.show_partition_request(collection_name)
 
         rf = self._stub.ShowPartitions.future(request, wait_for_ready=True, timeout=timeout)
         response = rf.result()
         status = response.status
         if status.error_code == 0:
-            return [p for p in response.values]
+            return list(response.partition_names)
 
         raise BaseException(status.error_code, status.reason)
 
@@ -347,11 +457,11 @@ class GrpcHandler(AbsMilvus):
 
         # if insert_param and not isinstance(insert_param, grpc_types.InsertParam):
         #     raise ParamError("The value of key 'insert_param' is invalid")
-        if insert_param and not isinstance(insert_param, service_msg_types.RowBatch):
+        if insert_param and not isinstance(insert_param, milvus_types.RowBatch):
             raise ParamError("The value of key 'insert_param' is invalid")
 
-        collection = Prepare.collection_name(collection_name)
-        rf = self._stub.DescribeCollection.future(collection, wait_for_ready=True, timeout=timeout)
+        collection_request = Prepare.describe_collection_request(collection_name)
+        rf = self._stub.DescribeCollection.future(collection_request, wait_for_ready=True, timeout=timeout)
         response = rf.result()
         if response.status.error_code != 0:
             raise BaseException(response.status.error_code, response.status.reason)
@@ -382,10 +492,11 @@ class GrpcHandler(AbsMilvus):
             if not ids:
                 ids = None
 
-        body = insert_param if insert_param \
-            else Prepare.bulk_insert_param(collection_name, entities, partition_tag, ids, params, fields_info, auto_id=auto_id)
+        requset = insert_param if insert_param \
+            else Prepare.bulk_insert_param(collection_name, entities, partition_tag, ids, params, fields_info,
+                                           auto_id=auto_id)
 
-        rf = self._stub.Insert.future(body, wait_for_ready=True, timeout=timeout)
+        rf = self._stub.Insert.future(requset, wait_for_ready=True, timeout=timeout)
         if kwargs.get("_async", False) is True:
             cb = kwargs.get("_callback", None)
             return InsertFuture(rf, cb)
@@ -393,7 +504,7 @@ class GrpcHandler(AbsMilvus):
         response = rf.result()
         if response.status.error_code == 0:
             if auto_id:
-                return list(range(response.begin, response.end))
+                return list(range(response.rowID_begin, response.rowID_end))
             return list(ids)
 
         raise BaseException(response.status.error_code, response.status.reason)
@@ -404,10 +515,10 @@ class GrpcHandler(AbsMilvus):
 
         # if insert_param and not isinstance(insert_param, grpc_types.InsertParam):
         #     raise ParamError("The value of key 'insert_param' is invalid")
-        if insert_param and not isinstance(insert_param, service_msg_types.RowBatch):
+        if insert_param and not isinstance(insert_param, milvus_types.RowBatch):
             raise ParamError("The value of key 'insert_param' is invalid")
 
-        collection = Prepare.collection_name(collection_name)
+        collection = Prepare.describe_collection_request(collection_name)
         rf = self._stub.DescribeCollection.future(collection, wait_for_ready=True, timeout=timeout)
         response = rf.result()
         if response.status.error_code != 0:
@@ -443,7 +554,8 @@ class GrpcHandler(AbsMilvus):
                 ids = None
 
         body = insert_param if insert_param \
-            else Prepare.insert_param(collection_name, entities, partition_tag, ids, params, fields_info, auto_id=auto_id)
+            else Prepare.insert_param(collection_name, entities, partition_tag, ids, params, fields_info,
+                                      auto_id=auto_id)
 
         rf = self._stub.Insert.future(body, wait_for_ready=True, timeout=timeout)
         if kwargs.get("_async", False) is True:
@@ -453,7 +565,7 @@ class GrpcHandler(AbsMilvus):
         response = rf.result()
         if response.status.error_code == 0:
             if auto_id:
-                return list(range(response.begin, response.end))
+                return list(range(response.rowID_begin, response.rowID_end))
             return list(ids)
 
         raise BaseException(response.status.error_code, response.status.reason)
@@ -461,12 +573,13 @@ class GrpcHandler(AbsMilvus):
     @error_handler(None)
     def search(self, collection_name, query_entities, partition_tags=None, fields=None, **kwargs):
         to = kwargs.get("timeout", None)
-        rf = self._stub.HasCollection.future(Prepare.collection_name(collection_name), wait_for_ready=True, timeout=to)
+        rf = self._stub.HasCollection.future(Prepare.has_collection_request(collection_name), wait_for_ready=True,
+                                             timeout=to)
         reply = rf.result()
         if reply.status.error_code != 0 or not reply.value:
             raise BaseException(reply.status.error_code, "collection not exists")
 
-        request = Prepare.search_param(collection_name, query_entities, partition_tags, fields)
+        request = Prepare.search_request(collection_name, query_entities, partition_tags, fields)
         self._search_hook.pre_search()
         ft = self._stub.Search.future(request, wait_for_ready=True, timeout=to)
         if kwargs.get("_async", False) is True:
@@ -492,7 +605,7 @@ class GrpcHandler(AbsMilvus):
 
     @error_handler()
     def create_index(self, collection_name, field_name, params, timeout=None, **kwargs):
-        index_param = Prepare.index_param(collection_name, field_name, params)
+        index_param = Prepare.create_index__request(collection_name, field_name, params)
         future = self._stub.CreateIndex.future(index_param, wait_for_ready=True, timeout=timeout)
         if kwargs.get('_async', False):
             cb = kwargs.get("_callback", None)
@@ -503,7 +616,7 @@ class GrpcHandler(AbsMilvus):
             raise BaseException(status.error_code, status.reason)
         sync = kwargs.get("sync", True)
         if sync:
-            self.wait_index_building_success(collection_name=collection_name, field_name= field_name)
+            self.wait_index_building_success(collection_name=collection_name, field_name=field_name)
         return Status(status.error_code, status.reason)
 
     @error_handler(None)
@@ -523,6 +636,7 @@ class GrpcHandler(AbsMilvus):
 
     @error_handler(False)
     def get_index_progress(self, collection_name, field_name, timeout=None, **kwargs):
+        ## TODO: which request where
         request = Prepare.describe_index_progress_request(collection_name, field_name)
 
         rf = self._stub.DescribeIndexProgress.future(request, wait_for_ready=True, timeout=timeout)
@@ -532,12 +646,24 @@ class GrpcHandler(AbsMilvus):
             return response.value
         raise BaseException(status.error_code, status.reason)
 
+    @error_handler(common_types.IndexState.FAILED)
+    def get_index_state(self, collection_name, field_name, timeout=None, **kwargs):
+        request = Prepare.get_index_state_request(collection_name, field_name)
+        rf = self._stub.GetIndexState.future(request, wait_for_ready=True, timeout=timeout)
+        response = rf.result()
+        status = response.status
+        if status.error_code == 0:
+            return response.state
+        raise BaseException(status.error_code, status.reason)
+
     @error_handler()
     def wait_index_building_success(self, collection_name, field_name, timeout=30, **kwargs):
+        def index_built():
+            return self.get_index_state(collection_name, field_name) == common_types.IndexState.FINISHED
         while True:
             time.sleep(0.5)
             print("\n***********  waiting for building index ***********\n")
-            if self.get_index_progress(collection_name=collection_name, field_name=field_name):
+            if index_built():
                 break
 
         return
