@@ -6,43 +6,21 @@ import ujson
 from .exceptions import ParamError
 
 from ..grpc_gen import milvus_pb2 as grpc_types
-from ..grpc_gen import status_pb2
 
 # for milvus-distributed
 from ..grpc_gen import common_pb2 as common_types
 from ..grpc_gen import schema_pb2 as schema_types
-from ..grpc_gen import service_pb2 as service_types
-from ..grpc_gen import service_msg_pb2 as service_msg_types
+from ..grpc_gen import milvus_pb2 as milvus_types
 
 from . import blob
 
 from .types import RangeType, DataType, MetricType, IndexType
 
-BoolOccurMap = {
-    "must": grpc_types.MUST,
-    "must_not": grpc_types.MUST_NOT,
-    "should": grpc_types.SHOULD
-}
-
-RangeOperatorMap = {
-    RangeType.LT: grpc_types.LT,
-    RangeType.LTE: grpc_types.LTE,
-    RangeType.EQ: grpc_types.EQ,
-    RangeType.GT: grpc_types.GT,
-    RangeType.GTE: grpc_types.GTE,
-    RangeType.NE: grpc_types.NE
-}
-
 
 class Prepare:
 
     @classmethod
-    def collection_name(cls, collection_name):
-
-        return service_msg_types.CollectionName(collection_name=collection_name)
-
-    @classmethod
-    def collection_schema(cls, collection_name, fields):
+    def create_collection_request(cls, collection_name, fields):
         """
         :type param: dict
         :param param: (Required)
@@ -129,7 +107,47 @@ class Prepare:
 
                 schema.fields.append(field_schema)
 
-        return schema
+        return milvus_types.CreateCollectionRequest(collection_name=collection_name, schema=bytes(schema.SerializeToString()))
+
+    @classmethod
+    def drop_collection_request(cls, collection_name):
+        return milvus_types.DropCollectionRequest(collection_name=collection_name)
+
+    @classmethod
+    def has_collection_request(cls, collection_name):
+        return milvus_types.HasCollectionRequest(collection_name=collection_name)
+
+    @classmethod
+    def describe_collection_request(cls, collection_name):
+        return milvus_types.DescribeCollectionRequest(collection_name=collection_name)
+
+    @classmethod
+    def collection_stats_request(cls, collection_name):
+        return milvus_types.CollectionStatsRequest(collection_name=collection_name)
+
+    @classmethod
+    def show_collection_request(cls):
+        return milvus_types.ShowCollectionRequest()
+
+    @classmethod
+    def create_partition_request(cls, collection_name, partition_name):
+        return milvus_types.CreatePartitionRequest(collection_name=collection_name, partition_name=partition_name)
+
+    @classmethod
+    def drop_partition_request(cls, collection_name, partition_name):
+        return milvus_types.DropPartitionRequest(collection_name=collection_name, partition_name=partition_name)
+
+    @classmethod
+    def has_partition_request(cls, collection_name, partition_name):
+        return milvus_types.HasPartitionRequest(collection_name=collection_name, partition_name=partition_name)
+
+    @classmethod
+    def partition_stats_request(cls, collection_name, partition_name):
+        return milvus_types.PartitionStatsRequest(collection_name=collection_name, partition_name=partition_name)
+
+    @classmethod
+    def show_partition_request(cls, collection_name):
+        return milvus_types.ShowPartitionRequest(collection_name=collection_name)
 
     @classmethod
     def empty(cls):
@@ -141,16 +159,15 @@ class Prepare:
             raise ParamError("collection_name must be of str type")
         if not isinstance(partition_tag, str):
             raise ParamError("partition_tag must be of str type")
-        return service_msg_types.PartitionName(collection_name=collection_name,
+        return milvus_types.PartitionName(collection_name=collection_name,
                                                tag=partition_tag)
 
     @classmethod
     def bulk_insert_param(cls, collection_name, entities, partition_tag, ids=None, params=None, fields_info=None,
                           **kwargs):
-        row_batch = service_msg_types.RowBatch()
-        row_batch.collection_name = collection_name
         default_partition_tag = "_default"  # should here?
-        row_batch.partition_tag = partition_tag or default_partition_tag
+        tag = partition_tag or default_partition_tag
+        insert_request = milvus_types.InsertRequest(collection_name=collection_name, partition_name=tag)
 
         row_data = list()
         fields_name = list()
@@ -240,21 +257,21 @@ class Prepare:
                     blob_row_data.value += blob.vectorFloatToBytes(field_value)
                 else:
                     raise ParamError("Unsupported data type!")
-            row_batch.row_data.append(blob_row_data)
+            insert_request.row_data.append(blob_row_data)
 
         # generate hash keys, TODO: better hash function
         if ids is not None:
             hash_keys = [len(str(e)) for e in ids]
-            row_batch.hash_keys.extend(hash_keys)
+            insert_request.hash_keys.extend(hash_keys)
 
-        return row_batch
+        return insert_request
 
     @classmethod
     def insert_param(cls, collection_name, entities, partition_tag, ids=None, params=None, fields_info=None, **kwargs):
-        row_batch = service_msg_types.RowBatch()
+        row_batch = milvus_types.InsertRequest()
         row_batch.collection_name = collection_name
         default_partition_tag = "_default"  # should here?
-        row_batch.partition_tag = partition_tag or default_partition_tag
+        row_batch.partition_name = partition_tag or default_partition_tag
 
         row_data = list()
         fields_type = list()
@@ -376,13 +393,13 @@ class Prepare:
         return row_batch
 
     @classmethod
-    def search_param(cls, collection_name, query_entities, partition_tags=None, fields=None, **kwargs):
+    def search_request(cls, collection_name, query_entities, partition_tags=None, fields=None, **kwargs):
         if not isinstance(query_entities, (dict,)):
             raise ParamError("Invalid query format. 'query_entities' must be a dict")
 
-        query = service_msg_types.Query(
+        request = milvus_types.SearchRequest(
             collection_name=collection_name,
-            partition_tags=partition_tags,
+            partition_names=partition_tags,
         )
 
         duplicated_entities = copy.deepcopy(query_entities)
@@ -413,33 +430,33 @@ class Prepare:
                     extract_vectors_param(item, placeholders)
 
         extract_vectors_param(duplicated_entities, vector_placeholders)
-        query.dsl = ujson.dumps(duplicated_entities)
+        request.dsl = ujson.dumps(duplicated_entities)
 
-        plg = service_msg_types.PlaceholderGroup()
+        plg = milvus_types.PlaceholderGroup()
         for tag, vectors in vector_placeholders.items():
             if len(vectors) <= 0:
                 continue
-            pl = service_msg_types.PlaceholderValue(tag=tag)
+            pl = milvus_types.PlaceholderValue(tag=tag)
 
             if isinstance(vectors[0], bytes):
-                pl.type = service_msg_types.PlaceholderType.VECTOR_BINARY
+                pl.type = milvus_types.PlaceholderType.VECTOR_BINARY
                 for vector in vectors:
                     pl.values.append(blob.vectorBinaryToBytes(vector))
             else:
-                pl.type = service_msg_types.PlaceholderType.VECTOR_FLOAT
+                pl.type = milvus_types.PlaceholderType.VECTOR_FLOAT
                 for vector in vectors:
                     pl.values.append(blob.vectorFloatToBytes(vector))
             # vector_values_bytes = service_msg_types.VectorValues.SerializeToString(vector_values)
 
             plg.placeholders.append(pl)
-        plg_str = service_msg_types.PlaceholderGroup.SerializeToString(plg)
-        query.placeholder_group = plg_str
+        plg_str = milvus_types.PlaceholderGroup.SerializeToString(plg)
+        request.placeholder_group = plg_str
 
-        return query
+        return request
 
     @classmethod
-    def index_param(cls, collection_name, field_name, params):
-        index_params = service_msg_types.IndexParam(collection_name=collection_name, field_name=field_name)
+    def create_index__request(cls, collection_name, field_name, params):
+        index_params = milvus_types.CreateIndexRequest(collection_name=collection_name, field_name=field_name)
         # index_params.collection_name = collection_name
         # index_params.field_name = field_name
 
@@ -460,10 +477,13 @@ class Prepare:
 
     @classmethod
     def describe_index_request(cls, collection_name, field_name):
-
-        return service_msg_types.DescribeIndexRequest(collection_name=collection_name, field_name=field_name)
+        return milvus_types.DescribeIndexRequest(collection_name=collection_name, field_name=field_name)
 
     @classmethod
     def describe_index_progress_request(cls, collection_name, field_name):
 
-        return service_msg_types.DescribeIndexProgressRequest(collection_name=collection_name, field_name=field_name)
+        return milvus_types.DescribeIndexProgressRequest(collection_name=collection_name, field_name=field_name)
+
+    @classmethod
+    def get_index_state_request(cls, collection_name, field_name):
+        return milvus_types.IndexStateRequest(collection_name=collection_name, field_name=field_name)
