@@ -135,7 +135,7 @@ class Milvus:
         numbers, letters, and underscores, and must not begin with a number.
         :type  str
         :param fields: Field parameters.
-        :type  fields: str
+        :type  fields: dict
 
         :raises:
             RpcError: If grpc encounter an error
@@ -289,6 +289,7 @@ class Milvus:
 
     @check_connect
     def get_partition_info(self, collection_name, partition_tag, timeout=30):
+        # TODO: This API could be deperated
         check_pass_param(collection_name=collection_name, partition_tag=partition_tag)
         with self._connection() as handler:
             return handler.get_partition_info(collection_name, partition_tag, timeout)
