@@ -7,8 +7,8 @@ import pytest
 import numpy as np
 
 from milvus import DataType
-from tests.utils import *
-from tests.constants import *
+from .utils import *
+from .constants import *
 
 uid = "test_search"
 nq = 1
@@ -146,7 +146,6 @@ class TestSearchBase:
         yield request.param
 
     # PASS
-    @pytest.mark.skip
     def test_search_flat(self, connect, collection, get_top_k, get_nq):
         '''
         target: test basic search function, all the search params is corrent, change top-k value
@@ -284,6 +283,7 @@ class TestSearchBase:
             assert res[0]._distances[0] < epsilon
             assert check_id_result(res[0], ids[0])
 
+    # DOG: TODO INVALID TYPE UNKNOWN
     @pytest.mark.skip("search_after_index_different_metric_type")
     def test_search_after_index_different_metric_type(self, connect, collection, get_simple_index):
         '''
@@ -455,6 +455,7 @@ class TestSearchBase:
     # test for ip metric
     #
     # TODO: reopen after we supporting ip flat
+    # DOG: TODO REDUCE
     @pytest.mark.skip("search_ip_flat")
     @pytest.mark.level(2)
     def test_search_ip_flat(self, connect, collection, get_simple_index, get_top_k, get_nq):
@@ -599,7 +600,6 @@ class TestSearchBase:
             res = connect.search(collection_name, default_query)
 
     # PASS
-    @pytest.mark.skip
     def test_search_distance_l2(self, connect, collection):
         '''
         target: search collection, and check the result: distance
@@ -648,6 +648,7 @@ class TestSearchBase:
         # TODO:
         # assert abs(np.sqrt(res[0]._distances[0]) - min_distance) <= tmp_epsilon
 
+    # DOG: TODO REDUCE
     # TODO: reopen after we supporting ip flat
     @pytest.mark.skip("search_distance_ip")
     @pytest.mark.level(2)
@@ -704,7 +705,7 @@ class TestSearchBase:
         # TODO:
         # assert abs(res[0]._distances[0] - max_distance) <= tmp_epsilon
 
-    @pytest.mark.skip("search_distance_jaccard_flat_index")
+    # PASS
     def test_search_distance_jaccard_flat_index(self, connect, binary_collection):
         '''
         target: search binary_collection, and check the result: distance
@@ -720,13 +721,14 @@ class TestSearchBase:
         res = connect.search(binary_collection, query)
         assert abs(res[0]._distances[0] - min(distance_0, distance_1)) <= epsilon
 
+    # DOG: TODO INVALID TYPE
     @pytest.mark.skip("search_distance_jaccard_flat_index_L2")
     @pytest.mark.level(2)
     def test_search_distance_jaccard_flat_index_L2(self, connect, binary_collection):
         '''
         target: search binary_collection, and check the result: distance
         method: compare the return distance value with value computed with L2
-        expected: the return distance equals to the computed value
+        expected: throw error of mismatched metric type
         '''
         nq = 1
         int_vectors, entities, ids = init_binary_data(connect, binary_collection, nb=2)
@@ -737,7 +739,7 @@ class TestSearchBase:
         with pytest.raises(Exception) as e:
             res = connect.search(binary_collection, query)
 
-    @pytest.mark.skip("search_distance_hamming_flat_index")
+    # PASS
     @pytest.mark.level(2)
     def test_search_distance_hamming_flat_index(self, connect, binary_collection):
         '''
@@ -754,7 +756,7 @@ class TestSearchBase:
         res = connect.search(binary_collection, query)
         assert abs(res[0][0].distance - min(distance_0, distance_1).astype(float)) <= epsilon
 
-    @pytest.mark.skip("search_distance_substructure_flat_index")
+    # PASS
     @pytest.mark.level(2)
     def test_search_distance_substructure_flat_index(self, connect, binary_collection):
         '''
@@ -772,7 +774,7 @@ class TestSearchBase:
         res = connect.search(binary_collection, query)
         assert len(res[0]) == 0
 
-    @pytest.mark.skip("search_distance_substructure_flat_index_B")
+    # PASS
     @pytest.mark.level(2)
     def test_search_distance_substructure_flat_index_B(self, connect, binary_collection):
         '''
@@ -791,7 +793,7 @@ class TestSearchBase:
         assert res[1][0].distance <= epsilon
         assert res[1][0].id == ids[1]
 
-    @pytest.mark.skip("search_distance_superstructure_flat_index")
+    # PASS
     @pytest.mark.level(2)
     def test_search_distance_superstructure_flat_index(self, connect, binary_collection):
         '''
@@ -809,7 +811,7 @@ class TestSearchBase:
         res = connect.search(binary_collection, query)
         assert len(res[0]) == 0
 
-    @pytest.mark.skip("search_distance_superstructure_flat_index_B")
+    # PASS
     @pytest.mark.level(2)
     def test_search_distance_superstructure_flat_index_B(self, connect, binary_collection):
         '''
@@ -830,7 +832,7 @@ class TestSearchBase:
         assert res[1][0].id in ids
         assert res[1][0].distance <= epsilon
 
-    @pytest.mark.skip("search_distance_tanimoto_flat_index")
+    # PASS
     @pytest.mark.level(2)
     def test_search_distance_tanimoto_flat_index(self, connect, binary_collection):
         '''
@@ -850,7 +852,6 @@ class TestSearchBase:
     # PASS
     @pytest.mark.level(2)
     @pytest.mark.timeout(30)
-    @pytest.mark.skip
     def test_search_concurrent_multithreads(self, connect, args):
         '''
         target: test concurrent search with multiprocessess
@@ -886,7 +887,6 @@ class TestSearchBase:
     # PASS
     @pytest.mark.level(2)
     @pytest.mark.timeout(30)
-    @pytest.mark.skip
     def test_search_concurrent_multithreads_single_connection(self, connect, args):
         '''
         target: test concurrent search with multiprocessess
@@ -920,7 +920,6 @@ class TestSearchBase:
 
     # PASS
     @pytest.mark.level(2)
-    @pytest.mark.skip
     def test_search_multi_collections(self, connect, args):
         '''
         target: test search multi collections of L2
@@ -971,7 +970,7 @@ class TestSearchDSL(object):
     ******************************************************************
     """
 
-    @pytest.mark.skip("query_no_must")
+    # PASS
     def test_query_no_must(self, connect, collection):
         '''
         method: build query without must expr
@@ -982,7 +981,7 @@ class TestSearchDSL(object):
         with pytest.raises(Exception) as e:
             res = connect.search(collection, query)
 
-    @pytest.mark.skip("query_no_vector_term_only")
+    # PASS
     def test_query_no_vector_term_only(self, connect, collection):
         '''
         method: build query without vector only term
@@ -1011,14 +1010,13 @@ class TestSearchDSL(object):
             res = connect.search(collection, query)
 
     # PASS
-    @pytest.mark.skip
     def test_query_vector_only(self, connect, collection):
         entities, ids = init_data(connect, collection)
         res = connect.search(collection, default_query)
         assert len(res) == nq
         assert len(res[0]) == default_top_k
 
-    @pytest.mark.skip("query_wrong_format")
+    # PASS
     def test_query_wrong_format(self, connect, collection):
         '''
         method: build query without must expr, with wrong expr name
@@ -1048,7 +1046,7 @@ class TestSearchDSL(object):
     ******************************************************************
     """
 
-    @pytest.mark.skip("query_term_value_not_in")
+    # PASS
     @pytest.mark.level(2)
     def test_query_term_value_not_in(self, connect, collection):
         '''
@@ -1064,8 +1062,7 @@ class TestSearchDSL(object):
         assert len(res[0]) == 0
         # TODO:
 
-    # TODO:
-    @pytest.mark.skip("query_term_value_all_in")
+    # PASS
     @pytest.mark.level(2)
     def test_query_term_value_all_in(self, connect, collection):
         '''
@@ -1080,8 +1077,7 @@ class TestSearchDSL(object):
         assert len(res[0]) == 1
         # TODO:
 
-    # TODO:
-    @pytest.mark.skip("query_term_values_not_in")
+    # PASS
     @pytest.mark.level(2)
     def test_query_term_values_not_in(self, connect, collection):
         '''
@@ -1097,7 +1093,7 @@ class TestSearchDSL(object):
         assert len(res[0]) == 0
         # TODO:
 
-    @pytest.mark.skip("query_term_values_all_in")
+    # PASS
     def test_query_term_values_all_in(self, connect, collection):
         '''
         method: build query with vector and term expr, with all term can be filtered
@@ -1116,7 +1112,7 @@ class TestSearchDSL(object):
                 assert result.id in ids[:limit]
         # TODO:
 
-    @pytest.mark.skip("query_term_values_parts_in")
+    # PASS
     def test_query_term_values_parts_in(self, connect, collection):
         '''
         method: build query with vector and term expr, with parts of term can be filtered
@@ -1132,8 +1128,7 @@ class TestSearchDSL(object):
         assert len(res[0]) == default_top_k
         # TODO:
 
-    # TODO:
-    @pytest.mark.skip("query_term_values_repeat")
+    # PASS
     @pytest.mark.level(2)
     def test_query_term_values_repeat(self, connect, collection):
         '''
@@ -1150,6 +1145,7 @@ class TestSearchDSL(object):
         assert len(res[0]) == 1
         # TODO:
 
+    # DOG: BUG, please fix
     @pytest.mark.skip("query_term_value_empty")
     def test_query_term_value_empty(self, connect, collection):
         '''
@@ -1162,7 +1158,7 @@ class TestSearchDSL(object):
         assert len(res) == nq
         assert len(res[0]) == 0
 
-    @pytest.mark.skip("query_complex_dsl")
+    # PASS
     def test_query_complex_dsl(self, connect, collection):
         '''
         method: query with complicated dsl
@@ -1184,8 +1180,7 @@ class TestSearchDSL(object):
     ******************************************************************
     """
 
-    # TODO
-    @pytest.mark.skip("query_term_key_error")
+    # PASS
     @pytest.mark.level(2)
     def test_query_term_key_error(self, connect, collection):
         '''
@@ -1205,7 +1200,7 @@ class TestSearchDSL(object):
     def get_invalid_term(self, request):
         return request.param
 
-    @pytest.mark.skip("query_term_wrong_format")
+    # PASS
     @pytest.mark.level(2)
     def test_query_term_wrong_format(self, connect, collection, get_invalid_term):
         '''
@@ -1219,6 +1214,7 @@ class TestSearchDSL(object):
         with pytest.raises(Exception) as e:
             res = connect.search(collection, query)
 
+    # DOG: PLEASE IMPLEMENT connect.count_entities
     # TODO
     @pytest.mark.skip("query_term_field_named_term")
     @pytest.mark.level(2)
@@ -1234,8 +1230,8 @@ class TestSearchDSL(object):
         ids = connect.bulk_insert(collection_term, term_entities)
         assert len(ids) == default_nb
         connect.flush([collection_term])
-        count = connect.count_entities(collection_term)
-        assert count == default_nb
+        count = connect.count_entities(collection_term) # count_entities is not impelmented
+        assert count == default_nb                      # removing these two lines, this test passed
         term_param = {"term": {"term": {"values": [i for i in range(default_nb // 2)]}}}
         expr = {"must": [gen_default_vector_expr(default_query),
                          term_param]}
@@ -1245,7 +1241,7 @@ class TestSearchDSL(object):
         assert len(res[0]) == default_top_k
         connect.drop_collection(collection_term)
 
-    @pytest.mark.skip("query_term_one_field_not_existed")
+    # PASS
     @pytest.mark.level(2)
     def test_query_term_one_field_not_existed(self, connect, collection):
         '''
@@ -1267,7 +1263,6 @@ class TestSearchDSL(object):
     """
 
     # PASS
-    # TODO
     def test_query_range_key_error(self, connect, collection):
         '''
         method: build query with range key error
@@ -1287,7 +1282,6 @@ class TestSearchDSL(object):
         return request.param
 
     # PASS
-    # TODO
     @pytest.mark.level(2)
     def test_query_range_wrong_format(self, connect, collection, get_invalid_range):
         '''
@@ -1318,7 +1312,6 @@ class TestSearchDSL(object):
 
     # PASS
     @pytest.mark.level(2)
-    @pytest.mark.skip
     def test_query_range_invalid_ranges(self, connect, collection):
         '''
         method: build query with invalid ranges
@@ -1356,7 +1349,7 @@ class TestSearchDSL(object):
         assert len(res) == nq
         assert len(res[0]) == default_top_k
 
-    @pytest.mark.skip("query_range_one_field_not_existed")
+    # PASS
     def test_query_range_one_field_not_existed(self, connect, collection):
         '''
         method: build query with two fields ranges, one of fields not existed
@@ -1376,9 +1369,7 @@ class TestSearchDSL(object):
     ************************************************************************
     """
 
-    # TODO
-    @pytest.mark.skip("query_multi_term_has_common")
-    @pytest.mark.level(2)
+    # PASS
     def test_query_multi_term_has_common(self, connect, collection):
         '''
         method: build query with multi term with same field, and values has common
@@ -1393,8 +1384,7 @@ class TestSearchDSL(object):
         assert len(res) == nq
         assert len(res[0]) == default_top_k
 
-    # TODO
-    @pytest.mark.skip("query_multi_term_no_common")
+    # PASS
     @pytest.mark.level(2)
     def test_query_multi_term_no_common(self, connect, collection):
         '''
@@ -1410,8 +1400,7 @@ class TestSearchDSL(object):
         assert len(res) == nq
         assert len(res[0]) == 0
 
-    # TODO
-    @pytest.mark.skip("query_multi_term_different_fields")
+    # PASS
     def test_query_multi_term_different_fields(self, connect, collection):
         '''
          method: build query with multi range with same field, and ranges no common
@@ -1427,8 +1416,7 @@ class TestSearchDSL(object):
         assert len(res) == nq
         assert len(res[0]) == 0
 
-    # TODO
-    @pytest.mark.skip("query_single_term_multi_fields")
+    # PASS
     @pytest.mark.level(2)
     def test_query_single_term_multi_fields(self, connect, collection):
         '''
@@ -1444,8 +1432,7 @@ class TestSearchDSL(object):
         with pytest.raises(Exception) as e:
             res = connect.search(collection, query)
 
-    # TODO
-    @pytest.mark.skip("query_multi_range_has_common")
+    # PASS
     @pytest.mark.level(2)
     def test_query_multi_range_has_common(self, connect, collection):
         '''
@@ -1461,8 +1448,7 @@ class TestSearchDSL(object):
         assert len(res) == nq
         assert len(res[0]) == default_top_k
 
-    # TODO
-    @pytest.mark.skip("query_multi_range_no_common")
+    # PASS
     @pytest.mark.level(2)
     def test_query_multi_range_no_common(self, connect, collection):
         '''
@@ -1478,8 +1464,7 @@ class TestSearchDSL(object):
         assert len(res) == nq
         assert len(res[0]) == 0
 
-    # TODO
-    @pytest.mark.skip("query_multi_range_different_fields")
+    # PASS
     @pytest.mark.level(2)
     def test_query_multi_range_different_fields(self, connect, collection):
         '''
@@ -1495,8 +1480,7 @@ class TestSearchDSL(object):
         assert len(res) == nq
         assert len(res[0]) == 0
 
-    # TODO
-    @pytest.mark.skip("query_single_range_multi_fields")
+    # PASS
     @pytest.mark.level(2)
     def test_query_single_range_multi_fields(self, connect, collection):
         '''
@@ -1518,8 +1502,7 @@ class TestSearchDSL(object):
     ******************************************************************
     """
 
-    # TODO
-    @pytest.mark.skip("query_single_term_range_has_common")
+    # PASS
     @pytest.mark.level(2)
     def test_query_single_term_range_has_common(self, connect, collection):
         '''
@@ -1535,8 +1518,7 @@ class TestSearchDSL(object):
         assert len(res) == nq
         assert len(res[0]) == default_top_k
 
-    # TODO
-    @pytest.mark.skip("query_single_term_range_no_common")
+    # PASS
     def test_query_single_term_range_no_common(self, connect, collection):
         '''
         method: build query with single term single range
@@ -1558,7 +1540,6 @@ class TestSearchDSL(object):
     """
 
     # PASS
-    # TODO
     def test_query_multi_vectors_same_field(self, connect, collection):
         '''
         method: build query with two vectors same field
@@ -1595,7 +1576,7 @@ class TestSearchDSLBools(object):
         with pytest.raises(Exception) as e:
             res = connect.search(collection, query)
 
-    @pytest.mark.skip("query_should_only_term")
+    # PASS
     def test_query_should_only_term(self, connect, collection):
         '''
         method: build query without must, with should.term instead
@@ -1606,7 +1587,7 @@ class TestSearchDSLBools(object):
         with pytest.raises(Exception) as e:
             res = connect.search(collection, query)
 
-    @pytest.mark.skip("query_should_only_vector")
+    # PASS
     def test_query_should_only_vector(self, connect, collection):
         '''
         method: build query without must, with should.vector instead
@@ -1617,7 +1598,7 @@ class TestSearchDSLBools(object):
         with pytest.raises(Exception) as e:
             res = connect.search(collection, query)
 
-    @pytest.mark.skip("query_must_not_only_term")
+    # PASS
     def test_query_must_not_only_term(self, connect, collection):
         '''
         method: build query without must, with must_not.term instead
@@ -1628,7 +1609,7 @@ class TestSearchDSLBools(object):
         with pytest.raises(Exception) as e:
             res = connect.search(collection, query)
 
-    @pytest.mark.skip("query_must_not_vector")
+    # PASS
     def test_query_must_not_vector(self, connect, collection):
         '''
         method: build query without must, with must_not.vector instead
@@ -1639,7 +1620,7 @@ class TestSearchDSLBools(object):
         with pytest.raises(Exception) as e:
             res = connect.search(collection, query)
 
-    @pytest.mark.skip("query_must_should")
+    # PASS
     def test_query_must_should(self, connect, collection):
         '''
         method: build query must, and with should.term
